pub const fn for_box<A: ?Sized>() -> SameLayout<*const A, Box<A>>Expand description
A proof that any box has same layout as a raw pointer.
pub const fn for_box<A: ?Sized>() -> SameLayout<*const A, Box<A>>A proof that any box has same layout as a raw pointer.